==> sale-3.5.3.jar: filiale/wenxi/sqls/handplanQuery.sql <==
select * from (
                  select cast(ROW_NUMBER() OVER(ORDER BY f_input_date desc) as int) z,
                         t.*,
                         case when f_whether_pay ='是'  then 0
                              else (isnull(f_oughtfee,0)-isnull(f_debt_money,0)+ isnull(overdue,0))
                             end f_actual_arrears
                  from (
                           select t.*,
                                  case when f_oughtamount<0 then 0 else f_oughtamount end f_oughtamount1,
                                  case when f_whether_pay ='是' then
                                           f_oughtfee
                                       else 0 end alloughtfee,
                                  isnull(convert(decimal(18,2),
                                                 CASE WHEN DATEDIFF(dd,f_end_date,getdate())<=0 or f_whether_pay ='是'  THEN
                                                          isnull(f_overdue_sh,0)
                                                      ELSE
                                                          --滞纳金天数大于0，若应交金额小于0
                                                          CASE WHEN overduedays*zhinajinbilv*(f_oughtfee-isnull(f_debt_money,0) -(case when minid is null  then 0 else f_balances end))<=0
                                                                   THEN
                                                                   isnull(f_latefee_ought,0)
                                                               ELSE
                                                                   --判断应交金额是否小于0
                                                                   (CASE WHEN overduedays*zhinajinbilv*(f_oughtfee-isnull(f_debt_money,0) -case when minid is null   then 0 else f_balances end)+isnull(f_latefee_ought,0)>=f_oughtfee-isnull(f_debt_money,0) -(case when minid is null  then 0 else f_balances end)
                                                                             THEN
                                                                             CASE WHEN f_oughtfee-isnull(f_debt_money,0) -(case when minid is null  then 0 else f_balances end)<0
                                                                                      THEN 0
                                                                                  ELSE
                                                                                          f_oughtfee-isnull(f_debt_money,0) -(case when minid is null  then 0 else f_balances end)
                                                                                 END
                                                                         ELSE
                                                                                     overduedays*zhinajinbilv*(f_oughtfee-isnull(f_debt_money,0) -(case when minid is null  then 0 else f_balances end))+isnull(f_latefee_ought,0)
                                                                       END)
                                                              END
                                                     END),0) overdue
                           from (
                                    select
                                        h.id,
                                        h.f_whether_pay,
                                        h.f_oughtfee,
                                        h.f_end_date,
                                        h.f_input_date,
                                        h.f_meter_classify,
                                        h.f_orgid,
                                        h.f_oughtamount,
                                        h.f_hand_state,
                                        h.f_userinfo_code,
                                        h.f_user_name,
                                        h.f_user_type,
                                        h.f_address,
                                        h.f_meternumber,
                                        h.f_last_tablebase,
                                        h.f_tablebase,
                                        h.f_balance,
                                        h.f_curbalance,
                                        h.f_accounts_state,
                                        h.f_hand_date,
                                        h.f_inputtor,
                                        h.f_input_person,
                                        h.f_result_state,
                                        h.f_meter_state,
                                        h.f_orgname,
                                        h.f_depname,
                                        h.f_operator,
                                        -- 瞬时流量
                                        h.f_instantaneous_flow,
                                        -- 压力
                                        h.f_pressure,
                                        -- 温度
                                        h.f_temperature,
                                        -- 流量计电量
                                        h.f_flowmeter_capacity,
                                        -- 控制器电量
                                        h.f_controller_power,
                                        -- 阀门开关
                                        h.f_valve_switch,
                                        hh1.*,
                                        { entity.findDialect() == $SqlServer$: $ substring(convert(varchar(100),convert(DATE,h.f_hand_date,20)),0,8) $,
                                        $  substr(to_char(h.f_operate_date,'yyyy-mm-dd hh24:mi:ss'),0,7)$}
                                        belongmonth,
                                        DATEDIFF(d,h.f_last_input_date,h.f_input_date)AS dd,
                                        CONVERT(VARCHAR(7),h.f_input_date,120) ym_data,
                                        h1.*,
                                        uf.f_hand_month,
                                        uf.f_table_state,
                                        h.f_haircut_gas,
                                        s.f_surplus_gas,
                                        s.f_operator f_sell_operator,
                                        s.f_privilege_money,
                                        sp.f_price_name,
                                        substring(convert(varchar(100),h.f_hand_date, 23),0,8)  f_rest_date,
                                        case when f_accounts_state = '自动下账' then h.f_input_date else s.f_operate_date end f_sellinggas_operate_date,
                                        tu.f_paper_account,
                                        tu.f_user_phone as phone,
                                        h.f_stair_gas1 f_stair1amount,h.f_stair_price1 f_stair1price,h.f_stair_money1 f_stair1fee,
                                        h.f_stair_gas2 f_stair2amount,h.f_stair_price2 f_stair2price,h.f_stair_money2 f_stair2fee,
                                        h.f_stair_gas3 f_stair3amount,h.f_stair_price3 f_stair3price,h.f_stair_money3 f_stair3fee,
                                        ua.f_zones,
                                        ua.f_residential_area,
                                        ib.f_bank_name,
                                        ISNULL(bgl.bgl,'0') f_bgl,
                                        DATEDIFF(dd,h.f_end_date,getdate()) overduedays, --滞纳天数 sql server
                                        CASE WHEN h.f_user_type='民用'
                                        THEN isnull((SELECT cast(value as float) FROM  t_singlevalue WHERE name='民用违约金' and f_filialeids=tu.f_orgids),(SELECT cast(value as float) FROM  t_singlevalue WHERE name='民用违约金'))
                                        ELSE
                                        isnull((SELECT cast(value as float) FROM  t_singlevalue WHERE name='非民用违约金' and f_filialeids=tu.f_orgids),(SELECT cast(value as float) FROM  t_singlevalue WHERE name='非民用违约金'))
                                        END zhinajinbilv,
                                        lr.f_latefee_ought,
                                        minids.minid minid,
                                        met.f_book_slice_area,
                                        f_dypayment,
                                        f_balances,
                                        uf.f_meter_book_num
                                    from t_handplan h
                                        left join (select f_old_id f_oldhand_id,f_operate_date f_corrhand_date,f_operator f_corrhand_operator from t_handplan where f_hand_state='撤销') hh1 on hh1.f_oldhand_id=h.id
                                        left join (select id,f_operate_date,f_surplus_gas,f_operator,f_privilege_money from t_sellinggas) s on s.id = h.f_sell_id
                                        left join (select f_hand_month,f_table_state,f_userfiles_id,f_meter_book_num from t_userfiles) uf on h.f_userfiles_id=uf.f_userfiles_id
                                        left join (select id f_meter_book_id,f_book_slice_area from t_meter_book) met on uf.f_meter_book_num = met.f_meter_book_id
                                        left join (
                                        select f_hand_id,sum(f_charge_money) f_charge_money,sum(f_debt_money) f_debt_money,sum(f_overdue) f_overdue_sh  from t_sellinghand where f_state='有效' group by f_hand_id
                                        ) h1 on h.id = h1.f_hand_id
                                        left join (
                                        select f_hand_id,sum(f_latefee_ought) f_latefee_ought
                                        from t_latefee_record where f_state='有效' group by f_hand_id
                                        ) lr on lr.f_hand_id = h.id
                                        left join (select f_slice_area as f_zones,f_userinfo_id,f_residential_area from t_user_address ) ua on h.f_userinfo_id= ua.f_userinfo_id
                                        left join (
                                        select
                                        f_userinfo_id,f_paper_account,f_user_phone,f_orgid f_orgids,
                                        case when f_cost_type='银行代扣' then f_cost_type else '现金缴费' end  f_dypayment,
                                        case when f_balance<0 then 0 else f_balance end f_balances
                                        from t_userinfo
                                        ) tu on h.f_userinfo_id= tu.f_userinfo_id
                                        left join
                                        (select f_userinfo_id,f_bank_name from t_infobank) ib on h.f_userinfo_id= ib.f_userinfo_id
                                        left join
                                        (select id,f_price_name from t_stairprice) sp on h.f_stairprice_id = sp.id
                                        left join (select f_userfiles_id ,'1' bgl from t_devices
                                        where f_devices_type = '壁挂炉'
                                        group  by f_userfiles_id) bgl on h.f_userfiles_id = bgl.f_userfiles_id
                                        left join (
                                        select min(id) minid,
                                        f_userfiles_id
                                        from t_handplan
                                        where f_hand_state = '有效' and f_meter_state = '已抄表'
                                        AND f_oughtfee>0 and f_whether_pay='否'
                                        group by f_userfiles_id
                                        ) minids on minids.f_userfiles_id=h.f_userfiles_id and minids.minid = h.id
                                ) t
                           where {condition} and f_hand_state !='作废'
                       ) t
              ) s order by z

==> sale-3.7.1.jar: filiale/wenxi/sqls/handplanQuery.sql <==
select * from (
                  select cast(ROW_NUMBER() OVER(ORDER BY f_input_date desc) as int) z,
                         t.*,
                         case when f_whether_pay ='是'  then 0
                              else (isnull(f_oughtfee,0)-isnull(f_debt_money,0)+ isnull(overdue,0))
                             end f_actual_arrears
                  from (
                           select t.*,
                                  case when f_oughtamount<0 then 0 else f_oughtamount end f_oughtamount1,
                                  case when f_whether_pay ='是' then
                                           f_oughtfee
                                       else 0 end alloughtfee,
                                  isnull(convert(decimal(18,2),
                                                 CASE WHEN DATEDIFF(dd,f_end_date,getdate())<=0 or f_whether_pay ='是'  THEN
                                                          isnull(f_overdue_sh,0)
                                                      ELSE
                                                          --滞纳金天数大于0，若应交金额小于0
                                                          CASE WHEN overduedays*zhinajinbilv*(f_oughtfee-isnull(f_debt_money,0) -(case when minid is null  then 0 else f_balances end))<=0
                                                                   THEN
                                                                   isnull(f_latefee_ought,0)
                                                               ELSE
                                                                   --判断应交金额是否小于0
                                                                   (CASE WHEN overduedays*zhinajinbilv*(f_oughtfee-isnull(f_debt_money,0) -case when minid is null   then 0 else f_balances end)+isnull(f_latefee_ought,0)>=f_oughtfee-isnull(f_debt_money,0) -(case when minid is null  then 0 else f_balances end)
                                                                             THEN
                                                                             CASE WHEN f_oughtfee-isnull(f_debt_money,0) -(case when minid is null  then 0 else f_balances end)<0
                                                                                      THEN 0
                                                                                  ELSE
                                                                                          f_oughtfee-isnull(f_debt_money,0) -(case when minid is null  then 0 else f_balances end)
                                                                                 END
                                                                         ELSE
                                                                                     overduedays*zhinajinbilv*(f_oughtfee-isnull(f_debt_money,0) -(case when minid is null  then 0 else f_balances end))+isnull(f_latefee_ought,0)
                                                                       END)
                                                              END
                                                     END),0) overdue
                           from (
                                    select
                                        h.id,
                                        h.f_whether_pay,
                                        h.f_oughtfee,
                                        h.f_end_date,
                                        h.f_input_date,
                                        h.f_meter_classify,
                                        h.f_orgid,
                                        h.f_oughtamount,
                                        h.f_hand_state,
                                        h.f_userinfo_code,
                                        h.f_user_name,
                                        h.f_user_type,
                                        h.f_gasproperties,
                                        h.f_depid,
                                        h.f_operatorid,
                                        h.f_address,
                                        h.f_meternumber,
                                        h.f_last_tablebase,
                                        h.f_tablebase,
                                        h.f_balance,
                                        h.f_curbalance,
                                        h.f_accounts_state,
                                        h.f_hand_date,
                                        h.f_inputtor,
                                        h.f_input_person,
                                        h.f_result_state,
                                        h.f_meter_state,
                                        h.f_orgname,
                                        h.f_depname,
                                        h.f_operator,
                                        -- 瞬时流量
                                        h.f_instantaneous_flow,
                                        -- 压力
                                        h.f_pressure,
                                        -- 温度
                                        h.f_temperature,
                                        -- 流量计电量
                                        h.f_flowmeter_capacity,
                                        -- 控制器电量
                                        h.f_controller_power,
                                        -- 阀门开关
                                        h.f_valve_switch,
                                        case when h.f_oughtamount > 0
                                            then
                                                case when datediff(day,h.f_last_input_date,h.f_input_date) > 0
                                                    then convert(decimal(18,2),h.f_oughtamount *1.0/ datediff(day,h.f_last_input_date,h.f_input_date))
                                                else h.f_oughtamount end
                                            else null
                                        end avg_oughtamount,
                                        hh1.*,
                                        { entity.findDialect() == $SqlServer$: $ substring(convert(varchar(100),convert(DATE,h.f_hand_date,20)),0,8) $,
                                        $  substr(to_char(h.f_operate_date,'yyyy-mm-dd hh24:mi:ss'),0,7)$}
                                        belongmonth,
                                        DATEDIFF(d,h.f_last_input_date,h.f_input_date)AS dd,
                                        CONVERT(VARCHAR(7),h.f_input_date,120) ym_data,
                                        h1.*,
                                        uf.f_hand_month,
                                        uf.f_table_state,
                                        h.f_haircut_gas,
                                        s.f_surplus_gas,
                                        s.f_operator f_sell_operator,
                                        s.f_privilege_money,
                                        sp.f_price_name,
                                        substring(convert(varchar(100),h.f_hand_date, 23),0,8)  f_rest_date,
                                        case when f_accounts_state = '自动下账' then h.f_input_date else s.f_operate_date end f_sellinggas_operate_date,
                                        tu.f_paper_account,
                                        tu.f_user_phone as phone,
                                        h.f_stair_gas1 f_stair1amount,h.f_stair_price1 f_stair1price,h.f_stair_money1 f_stair1fee,
                                        h.f_stair_gas2 f_stair2amount,h.f_stair_price2 f_stair2price,h.f_stair_money2 f_stair2fee,
                                        h.f_stair_gas3 f_stair3amount,h.f_stair_price3 f_stair3price,h.f_stair_money3 f_stair3fee,
                                        ua.f_zones,
                                        ua.f_residential_area,
                                        ib.f_bank_name,
                                        ISNULL(bgl.bgl,'0') f_bgl,
                                        DATEDIFF(dd,h.f_end_date,getdate()) overduedays, --滞纳天数 sql server
                                        CASE WHEN h.f_user_type='民用'
                                        THEN isnull((SELECT cast(value as float) FROM  t_singlevalue WHERE name='民用违约金' and f_filialeids=tu.f_orgids),(SELECT cast(value as float) FROM  t_singlevalue WHERE name='民用违约金'))
                                        ELSE
                                        isnull((SELECT cast(value as float) FROM  t_singlevalue WHERE name='非民用违约金' and f_filialeids=tu.f_orgids),(SELECT cast(value as float) FROM  t_singlevalue WHERE name='非民用违约金'))
                                        END zhinajinbilv,
                                        lr.f_latefee_ought,
                                        minids.minid minid,
                                        met.f_book_slice_area,
                                        f_dypayment,
                                        f_balances,
                                        uf.f_meter_book_num
                                    from t_handplan h
                                        left join (select f_old_id f_oldhand_id,f_operate_date f_corrhand_date,f_operator f_corrhand_operator from t_handplan where f_hand_state='撤销') hh1 on hh1.f_oldhand_id=h.id
                                        left join (select id,f_operate_date,f_surplus_gas,f_operator,f_privilege_money from t_sellinggas) s on s.id = h.f_sell_id
                                        left join (select f_hand_month,f_table_state,f_userfiles_id,f_meter_book_num from t_userfiles) uf on h.f_userfiles_id=uf.f_userfiles_id
                                        left join (select id f_meter_book_id,f_book_slice_area from t_meter_book) met on uf.f_meter_book_num = met.f_meter_book_id
                                        left join (
                                        select f_hand_id,sum(f_charge_money) f_charge_money,sum(f_debt_money) f_debt_money,sum(f_overdue) f_overdue_sh  from t_sellinghand where f_state='有效' group by f_hand_id
                                        ) h1 on h.id = h1.f_hand_id
                                        left join (
                                        select f_hand_id,sum(f_latefee_ought) f_latefee_ought
                                        from t_latefee_record where f_state='有效' group by f_hand_id
                                        ) lr on lr.f_hand_id = h.id
                                        left join (select f_slice_area as f_zones,f_userinfo_id,f_residential_area from t_user_address ) ua on h.f_userinfo_id= ua.f_userinfo_id
                                        left join (
                                        select
                                        f_userinfo_id,f_paper_account,f_user_phone,f_orgid f_orgids,
                                        case when f_cost_type='银行代扣' then f_cost_type else '现金缴费' end  f_dypayment,
                                        case when f_balance<0 then 0 else f_balance end f_balances
                                        from t_userinfo
                                        ) tu on h.f_userinfo_id= tu.f_userinfo_id
                                        left join
                                        (select f_userinfo_id,f_bank_name from t_infobank) ib on h.f_userinfo_id= ib.f_userinfo_id
                                        left join
                                        (select id,f_price_name from t_stairprice) sp on h.f_stairprice_id = sp.id
                                        left join (select f_userfiles_id ,'1' bgl from t_devices
                                        where f_devices_type = '壁挂炉'
                                        group  by f_userfiles_id) bgl on h.f_userfiles_id = bgl.f_userfiles_id
                                        left join (
                                        select min(id) minid,
                                        f_userfiles_id
                                        from t_handplan
                                        where f_hand_state = '有效' and f_meter_state = '已抄表'
                                        AND f_oughtfee>0 and f_whether_pay='否'
                                        group by f_userfiles_id
                                        ) minids on minids.f_userfiles_id=h.f_userfiles_id and minids.minid = h.id
                                ) t
                           where {condition} and f_hand_state !='作废'
                       ) t
              ) s order by z
